spawn

Function spawn 

fn spawn(f: impl Future<Output = ()> + 'static)
Runs a future to completion. On native this blocks via pollster, on wasm this spawns a local task. This allows the same async wgpu initialization code to work on both platforms.