struct SurfaceWrapper {
surface: Option<Surface<'static>>,
config: Option<SurfaceConfiguration>,
}Expand description
Wrapper type which manages the surface and surface configuration.
As surface usage varies per platform, wrapping this up cleans up the event loop code.
Fields
surface: Option<Surface<'static>>config: Option<SurfaceConfiguration>Implementations
Sourceimpl SurfaceWrapper
impl SurfaceWrapper
Sourcefn pre_adapter(&mut self, instance: &Instance, window: Arc<Window>)
fn pre_adapter(&mut self, instance: &Instance, window: Arc<Window>)
Called after the instance is created, but before we request an adapter.
On wasm, we need to create the surface here, as the WebGL backend needs a surface (and hence a canvas) to be present to create the adapter.
We cannot unconditionally create a surface here, as Android requires
us to wait until we receive the Resumed event to do so.
Sourcefn resume(&mut self, context: &ExampleContext, window: Arc<Window>, srgb: bool)
fn resume(&mut self, context: &ExampleContext, window: Arc<Window>, srgb: bool)
Called on resume to create (on native) and configure the surface.
On all native platforms, this is where we create the surface.
On wasm, the surface was already created in Self::pre_adapter.
Additionally, we configure the surface based on the (now valid) window size.
Sourcefn resize(&mut self, context: &ExampleContext, size: PhysicalSize<u32>)
fn resize(&mut self, context: &ExampleContext, size: PhysicalSize<u32>)
Resize the surface, making sure to not resize to zero.
Sourcefn acquire(
&mut self,
context: &ExampleContext,
window: Arc<Window>,
) -> Option<SurfaceTexture>
fn acquire( &mut self, context: &ExampleContext, window: Arc<Window>, ) -> Option<SurfaceTexture>
Acquire the next surface texture.
Returns None on failure.
Sourcefn suspend(&mut self)
fn suspend(&mut self)
On suspend on android, we drop the surface, as it’s no longer valid.
A suspend event is always followed by at least one resume event.
fn get(&self) -> Option<&Surface<'static>>
fn config(&self) -> &SurfaceConfiguration